@@ -8,8 +8,7 @@ from trytond.transaction import Transaction
 __all__ = ['Move']
 
 
-class Move:
-    __metaclass__ = PoolMeta
+class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
     fifo_quantity = fields.Float('FIFO Quantity')
 
